==> core-0.9.125-sources.jar: de/quantummaid/httpmaid/mappath/MapPathException.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.mappath;

import static de.quantummaid.httpmaid.mappath.exposition.Exposition.renderOneLinePositionExposition;
import static java.lang.String.format;

public final class MapPathException extends RuntimeException {

    private MapPathException(final String message) {
        super(message);
    }

    public static MapPathException parseException(final String message,
                                                  final String input,
                                                  final int index) {
        final String exposition = renderOneLinePositionExposition(input, index);
        final String fullMessage = format("error parsing '%s' at position %d: %s%n%s",
                input, index, message, exposition);
        return new MapPathException(fullMessage);
    }
}

==> core-0.9.144-sources.jar: de/quantummaid/httpmaid/mappath/MapPathException.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.mappath;

import static de.quantummaid.httpmaid.mappath.exposition.Exposition.renderOneLinePositionExposition;
import static java.lang.String.format;

public final class MapPathException extends RuntimeException {

    private MapPathException(final String message) {
        super(message);
    }

    public static MapPathException parseException(final String message,
                                                  final String input,
                                                  final int index) {
        final String exposition = renderOneLinePositionExposition(input, index);
        final String fullMessage = format("error parsing '%s' at position %d: %s%n%s",
                input, index, message, exposition);
        return new MapPathException(fullMessage);
    }

    public static MapPathException retrievalException(final String message) {
        return new MapPathException(message);
    }
}
